"""
Copyright (C) JheysonDev ~ All right reserved
"""
from colorama import init, Fore, Style


class Error:
    def __init__(self, msg: str = "Undefined error message"):
        self.msg: str = msg

    def run(self):
        print(
            Fore.RED
            + Style.BRIGHT
            + "Error: "
            + Fore.RESET
            + Style.RESET_ALL
            + self.msg
        )



"""
Copyright (C) JheysonDev ~ All right reserved
"""
import os
import platform


class CleanCommand:
    def __init__(self):
        self.command: str = ""

    def run(self):
        platform_name = platform.system()
        if platform_name == "Linux":
            self.command = "clear"
        elif platform_name == "Windows":
            self.command = "cls"
        elif platform_name == "Darwin":
            self.command = "clear"
        else:
            self.command = "clear"
        os.system(self.command)



"""
Copyright (C) JheysonDev ~ All right reserved
"""
from commands import Close, Clean, Print, Exec, Env
from utils import Error
from colorama import Fore


class Main:
    def __init__(self, prompt="-| "):
        self.prompt = prompt
        self.cli = input(self.prompt)

    def shell(self):
        while self.cli >= "":
            command: list = self.cli.split(" ", 1)
            if command[0] == "print":
                Print.PrintCommand(command[1]).run()
            elif command[0] == "clean":
                Clean.CleanCommand().run()
            elif command[0] == "close":
                Close.CloseCommand().run()
            elif command[0] == "exec":
                Exec.ExecCommand(command[1]).run()
            elif command[0] == "env":
                Env.EnvCommand(command[1]).run()
            elif command[0] == "":
                Error.Error("You must enter a command").run()
            else:
                Error.Error("Command no found").run()
            self.cli = input(self.prompt)


if __name__ == "__main__":
    main = Main()
    main.shell()



"""
Copyright (C) JheysonDev ~ All right reserved
"""
from colorama import init, Fore, Style


class Warning:
    def __init__(self, msg="Undefined warning message"):
        self.msg = msg

    def run(self):
        print(
            Fore.YELLOW
            + Style.BRIGHT
            + "Warning: "
            + Fore.RESET
            + Style.RESET_ALL
            + self.msg
        )



"""
Copyright (C) JheysonDev ~ All right reserved
"""
import os
from utils import Error


class ExecCommand:
    def __init__(self, args=""):
        self.path = os.getenv("PATH").split(":")
        self.args = args.split(" ", 1)
        self.iterations = len(self.path)

    def run(self):
        for b in self.path:
            if os.path.exists("{0}/{1}".format(b, self.args[0])) is True:
                os.system("{0}/{1}".format(b, self.args[0]))
            else:
                self.iterations = self.iterations - 1
                if self.iterations == 0:
                    Error.Error(
                        "no executable with the name of '{0}' was found in the path".format(
                            self.args[0]
                        )
                    ).run()



"""
Copyright (C) JheysonDev ~ All right reserved
"""
import sys


class CloseCommand:
    def __init__(self, code=0, msg=""):
        self.exit_code: int = code
        self.msg: str = msg

    def run(self):
        print(f"Exit: {self.exit_code}, {self.msg}")
        sys.exit(self.exit_code)



"""
Copyright (C) JheysonDev ~ All right reserved
"""
import os


class EnvCommand:
    def __init__(self, args: str):
        self.args = args.split(" ", 1)
        self.env_name = self.args[0]
        self.env_value = ""

    def run(self):
        if len(self.args) == 2:
            self.env_value = self.args[1]
        if self.env_value <= "":
            print(os.getenv(self.env_name))
        if self.env_value >= "":
            os.environ[self.env_name] = self.env_value



from setuptools import setup, find_packages

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name="catsh",
    version="0.1.3",
    author="JheysonDev",
    url="https://github.com/JheysonDev/catsh",
    license="GNU Public License",
    packages=find_packages(),
    description="A cross-platform shell write in python",
    long_description=long_description,
    long_description_content_type="text/markdown",
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
        "Topic :: Utilities",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
    ],
    python_requires=">=3.6",
)



"""
Copyright (C) JheysonDev ~ All right reserved
"""
import os
import platform


class Config:
    def __init__(self):
        self.prompt: str
        self.prompt_color: str
        self.commands: dict
        self.config_file: str
        self.home_path: str = ""
        self.platform_name: str = ""

    def platform(self):
        self.platform_name = platform.system()
        print(self.platform_name)

    def paths(self):
        if self.platform_name == "Linux" or "Darwin":
            self.home_path = os.path.expanduser("~")
        elif self.platform_name == "Windows":
            self.home_path = os.path.expanduser("%USERPROFILE%")

    def prompt(self):
        self.prompt = "-| "


config = Config()
config.platform()